/***
 * Dispatches the result of a Promise that could be either a success or an error.
 * @param promise The promise whose result will be dispatched.
 * @param action The action to dispatch.
 * @param dispatch The dispatch function provided by the middleware.
 * @returns The promise whose result will be dispatched.
 */
declare function dispatchPromiseResult(promise: Promise<any>, action: any, dispatch: any): Promise<any>;
/**
 * Checks if an action is a Flux Standard Action (FSA).
 * For more info, see https://github.com/redux-utilities/flux-standard-action#actions
 * @param action The action to be evaluated
 * @returns `true` if the action received via argument is an FSA.
 */
declare function isFSA(action?: any): boolean;
/**
 * Checks if an action is thenable.
 * For more info, see https://promisesaplus.com/#point-53
 * @param action The action to be evaluated
 * @returns `true` if the action received via argument is a thenable.
 */
declare function isThenable(action?: any): boolean;
/**
 * Checks if an action a function.
 * For more info, see https://github.com/gaearon/redux-thunk#whats-a-thunk
 * @param action The element to be evaluated.
 * @return `true` if the action received via argument is a function.
 */
declare function isFunction(action?: any): boolean;
export { dispatchPromiseResult, isFSA, isThenable, isFunction };
